@@ -51,6 +51,9 @@
 #endif
 #include <stdarg.h>
 #include <linux/uaccess.h>
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(4, 11, 0)
+#include <linux/sched/signal.h>
+#endif
 #include <net/sock.h>
 #include <net/af_unix.h>
 #include <net/ip.h>
@@ -1095,7 +1098,7 @@ static inline size_t cs_ksize(const void *obj)
  */
 struct cs_security {
 	struct list_head list;
-#if LINUX_VERSION_CODE < KERNEL_VERSION(2, 6, 29)
+#if LINUX_VERSION_CODE < KERNEL_VERSION(2, 6, 29) || LINUX_VERSION_CODE >= KERNEL_VERSION(4, 12, 0)
 	const struct task_struct *task;
 #else
 	struct pid *pid; /* Maybe NULL. */
