@@ -3,7 +3,7 @@
  *
  * Copyright (C) 2005-2012  NTT DATA CORPORATION
  *
- * Version: 0.2   2016/10/05
+ * Version: 0.2.1   2017/02/20
  */
 
 #include "internal.h"
@@ -150,11 +150,28 @@ static bool cs_domain_used_by_task(struct cs_domain_info *domain)
 	}
 out:
 	rcu_read_unlock();
+#elif LINUX_VERSION_CODE >= KERNEL_VERSION(3, 14, 0) || defined(for_each_process_thread)
+	struct task_struct *g;
+	struct task_struct *t;
+
+	rcu_read_lock();
+	for_each_process_thread(g, t) {
+		if (!(t->cs_flags & CS_TASK_IS_IN_EXECVE)) {
+			smp_rmb(); /* Avoid out of order execution. */
+			if (t->cs_domain_info != domain)
+				continue;
+		}
+		in_use = true;
+		goto out;
+	}
+out:
+	rcu_read_unlock();
 #else
 	struct task_struct *g;
 	struct task_struct *t;
 
-	cs_tasklist_lock();
+	rcu_read_lock();
+	read_lock(&tasklist_lock);
 	do_each_thread(g, t) {
 		if (!(t->cs_flags & CS_TASK_IS_IN_EXECVE)) {
 			smp_rmb(); /* Avoid out of order execution. */
@@ -165,7 +182,8 @@ out:
 		goto out;
 	} while_each_thread(g, t);
 out:
-	cs_tasklist_unlock();
+	read_unlock(&tasklist_lock);
+	rcu_read_unlock();
 #endif
 	return in_use;
 }
