@@ -52,6 +52,9 @@
 #endif
 #include <stdarg.h>
 #include <linux/uaccess.h>
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(4, 11, 0)
+#include <linux/sched/signal.h>
+#endif
 #include <net/sock.h>
 #include <net/af_unix.h>
 #include <net/ip.h>
