@@ -266,18 +266,17 @@ static struct security_hook_list caitsith_hooks[] = {
 #endif
 };
 
-static void cs_add_hooks(void)
+static int __init cs_add_hooks(void)
 {
+	if (caitsith_ops.disabled)
+		return 0;
 #if LINUX_VERSION_CODE >= KERNEL_VERSION(4, 11, 0)
-	int i;
-
-	for (i = 0; i < ARRAY_SIZE(caitsith_hooks); i++) {
-		caitsith_hooks[i].lsm = "caitsith";
-		list_add_tail_rcu(&caitsith_hooks[i].list,
-				  caitsith_hooks[i].head);
-	}
+	security_add_hooks(caitsith_hooks, ARRAY_SIZE(caitsith_hooks),
+			   "caitsith");
 #else
 	security_add_hooks(caitsith_hooks, ARRAY_SIZE(caitsith_hooks));
 #endif
+	return 0;
 }
+late_initcall(cs_add_hooks);
 #endif /* LINUX_VERSION_CODE >= KERNEL_VERSION(4, 2, 0) && defined(CONFIG_SECURITY) */
